import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { KafkaClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KafkaClient";
import { CreateClusterV2Request, CreateClusterV2Response } from "../models/models_0";
export interface CreateClusterV2CommandInput extends CreateClusterV2Request {
}
export interface CreateClusterV2CommandOutput extends CreateClusterV2Response, __MetadataBearer {
}
/**
 * <p>Creates a new MSK cluster.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KafkaClient, CreateClusterV2Command } from "@aws-sdk/client-kafka"; // ES Modules import
 * // const { KafkaClient, CreateClusterV2Command } = require("@aws-sdk/client-kafka"); // CommonJS import
 * const client = new KafkaClient(config);
 * const command = new CreateClusterV2Command(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateClusterV2CommandInput} for command's `input` shape.
 * @see {@link CreateClusterV2CommandOutput} for command's `response` shape.
 * @see {@link KafkaClientResolvedConfig | config} for KafkaClient's `config` shape.
 *
 */
export declare class CreateClusterV2Command extends $Command<CreateClusterV2CommandInput, CreateClusterV2CommandOutput, KafkaClientResolvedConfig> {
    readonly input: CreateClusterV2CommandInput;
    constructor(input: CreateClusterV2CommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: KafkaClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateClusterV2CommandInput, CreateClusterV2CommandOutput>;
    private serialize;
    private deserialize;
}
