import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { KafkaClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KafkaClient";
import { DeleteConfigurationRequest, DeleteConfigurationResponse } from "../models/models_0";
export interface DeleteConfigurationCommandInput extends DeleteConfigurationRequest {
}
export interface DeleteConfigurationCommandOutput extends DeleteConfigurationResponse, __MetadataBearer {
}
/**
 * <p>Deletes an MSK Configuration.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KafkaClient, DeleteConfigurationCommand } from "@aws-sdk/client-kafka"; // ES Modules import
 * // const { KafkaClient, DeleteConfigurationCommand } = require("@aws-sdk/client-kafka"); // CommonJS import
 * const client = new KafkaClient(config);
 * const command = new DeleteConfigurationCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DeleteConfigurationCommandInput} for command's `input` shape.
 * @see {@link DeleteConfigurationCommandOutput} for command's `response` shape.
 * @see {@link KafkaClientResolvedConfig | config} for KafkaClient's `config` shape.
 *
 */
export declare class DeleteConfigurationCommand extends $Command<DeleteConfigurationCommandInput, DeleteConfigurationCommandOutput, KafkaClientResolvedConfig> {
    readonly input: DeleteConfigurationCommandInput;
    constructor(input: DeleteConfigurationCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: KafkaClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DeleteConfigurationCommandInput, DeleteConfigurationCommandOutput>;
    private serialize;
    private deserialize;
}
