import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { KafkaClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KafkaClient";
import { DescribeClusterV2Request, DescribeClusterV2Response } from "../models/models_0";
export interface DescribeClusterV2CommandInput extends DescribeClusterV2Request {
}
export interface DescribeClusterV2CommandOutput extends DescribeClusterV2Response, __MetadataBearer {
}
/**
 * <p>Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KafkaClient, DescribeClusterV2Command } from "@aws-sdk/client-kafka"; // ES Modules import
 * // const { KafkaClient, DescribeClusterV2Command } = require("@aws-sdk/client-kafka"); // CommonJS import
 * const client = new KafkaClient(config);
 * const command = new DescribeClusterV2Command(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeClusterV2CommandInput} for command's `input` shape.
 * @see {@link DescribeClusterV2CommandOutput} for command's `response` shape.
 * @see {@link KafkaClientResolvedConfig | config} for KafkaClient's `config` shape.
 *
 */
export declare class DescribeClusterV2Command extends $Command<DescribeClusterV2CommandInput, DescribeClusterV2CommandOutput, KafkaClientResolvedConfig> {
    readonly input: DescribeClusterV2CommandInput;
    constructor(input: DescribeClusterV2CommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: KafkaClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeClusterV2CommandInput, DescribeClusterV2CommandOutput>;
    private serialize;
    private deserialize;
}
