import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { KafkaClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KafkaClient";
import { ListClustersV2Request, ListClustersV2Response } from "../models/models_0";
export interface ListClustersV2CommandInput extends ListClustersV2Request {
}
export interface ListClustersV2CommandOutput extends ListClustersV2Response, __MetadataBearer {
}
/**
 * <p>Returns a list of all the MSK clusters in the current Region.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KafkaClient, ListClustersV2Command } from "@aws-sdk/client-kafka"; // ES Modules import
 * // const { KafkaClient, ListClustersV2Command } = require("@aws-sdk/client-kafka"); // CommonJS import
 * const client = new KafkaClient(config);
 * const command = new ListClustersV2Command(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListClustersV2CommandInput} for command's `input` shape.
 * @see {@link ListClustersV2CommandOutput} for command's `response` shape.
 * @see {@link KafkaClientResolvedConfig | config} for KafkaClient's `config` shape.
 *
 */
export declare class ListClustersV2Command extends $Command<ListClustersV2CommandInput, ListClustersV2CommandOutput, KafkaClientResolvedConfig> {
    readonly input: ListClustersV2CommandInput;
    constructor(input: ListClustersV2CommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: KafkaClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListClustersV2CommandInput, ListClustersV2CommandOutput>;
    private serialize;
    private deserialize;
}
