import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { KafkaClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KafkaClient";
import { UpdateConnectivityRequest, UpdateConnectivityResponse } from "../models/models_0";
export interface UpdateConnectivityCommandInput extends UpdateConnectivityRequest {
}
export interface UpdateConnectivityCommandOutput extends UpdateConnectivityResponse, __MetadataBearer {
}
/**
 * <p>Updates the cluster's connectivity configuration.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KafkaClient, UpdateConnectivityCommand } from "@aws-sdk/client-kafka"; // ES Modules import
 * // const { KafkaClient, UpdateConnectivityCommand } = require("@aws-sdk/client-kafka"); // CommonJS import
 * const client = new KafkaClient(config);
 * const command = new UpdateConnectivityCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link UpdateConnectivityCommandInput} for command's `input` shape.
 * @see {@link UpdateConnectivityCommandOutput} for command's `response` shape.
 * @see {@link KafkaClientResolvedConfig | config} for KafkaClient's `config` shape.
 *
 */
export declare class UpdateConnectivityCommand extends $Command<UpdateConnectivityCommandInput, UpdateConnectivityCommandOutput, KafkaClientResolvedConfig> {
    readonly input: UpdateConnectivityCommandInput;
    constructor(input: UpdateConnectivityCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: KafkaClientResolvedConfig, options?: __HttpHandlerOptions): Handler<UpdateConnectivityCommandInput, UpdateConnectivityCommandOutput>;
    private serialize;
    private deserialize;
}
